@@ -96,7 +96,7 @@ class Autoencoder(Learner):
             raise AssertionError('Model is None.')
 
         self.model.compile(loss='mse', optimizer='adam')
-        early_stopping = EarlyStopping(patience=10, min_delta=1e-3)
+        early_stopping = EarlyStopping(monitor='loss', patience=10, min_delta=1e-3)
         self.model.fit(self.x_train, self.x_train,
                        epochs=self.n_epochs, callbacks=[early_stopping])
         self.learner = self.model
